==> e107_0.7.23_full.tar.gz: e107_languages/English/admin/lan_users_extended.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $Source: /cvs_backup/e107_0.7/e107_languages/English/admin/lan_users_extended.php,v $
|     $Revision: 11346 $
|     $Date: 2010-02-17 12:56:14 -0600 (Wed, 17 Feb 2010) $
|     $Author: secretr $
+----------------------------------------------------------------------------+
*/
define("EXTLAN_1", "Name");
define("EXTLAN_2", "Preview");
define("EXTLAN_3", "Values");
define("EXTLAN_4", "Req'd");
define("EXTLAN_5", "Applicable");
define("EXTLAN_6", "Read access");
define("EXTLAN_7", "Write access");
define("EXTLAN_8", "Action");
define("EXTLAN_9", "Extended User Fields");

define("EXTLAN_10", "Field name");
define("EXTLAN_11", "This is the name of the field as stored in the table, it must be unique from any other, and must not be used in the main user table");
define("EXTLAN_12", "Field text");
define("EXTLAN_13", "This is the displayed name of the field in rendered pages");
define("EXTLAN_14", "Field Type");
define("EXTLAN_15", "Field include text");
define("EXTLAN_16", "Default Value");
define("EXTLAN_17", "Enter each possible value on each line <br /> For DB table see help.");
define("EXTLAN_18", "Required");
define("EXTLAN_19", "Users will be required to enter a value in this field when updating their settings.");
define("EXTLAN_20", "Determines which users this field will apply to.");
define("EXTLAN_21", "This will determine who will see this field in their usersettings.");
define("EXTLAN_22", "This will determine who can see the value in the user page <br />NOTE: Setting this to 'Read Only' will make it visible to Admin and the member only.");
define("EXTLAN_23", "Add Extended Field");
define("EXTLAN_24", "Update Extended Field");
define("EXTLAN_25", "move down");
define("EXTLAN_26", "move up");
define("EXTLAN_27", "Confirm Delete");
define("EXTLAN_28", "No extended fields defined");
define("EXTLAN_29", "Extended user fields saved.");
define("EXTLAN_30", "Extended field deleted");
// define("EXTLAN_31", "Extended Field Menu");
// define("EXTLAN_32", "Extended front page");
define("EXTLAN_33", "Cancel Edit");
define("EXTLAN_34", "Extended Fields");
define("EXTLAN_35", "Categories");
define("EXTLAN_36", "No assigned Category");
define("EXTLAN_37", "No categories defined");
define("EXTLAN_38", "Category name");
define("EXTLAN_39", "Add category");
define("EXTLAN_40", "Category created");
define("EXTLAN_41", "Category deleted");
define("EXTLAN_42", "Update Category");
define("EXTLAN_43", "Category Updated");
define("EXTLAN_44", "Category");
define("EXTLAN_45", "Add New Field");
define("EXTLAN_46", "Help");
define("EXTLAN_47", "Add new parameter");
define("EXTLAN_48", "Add new value");
define("EXTLAN_49", "Allow user to hide");
define("EXTLAN_50", "Setting this to yes will allow the user to hide this value from non-admins");
define("EXTLAN_51", "Any valid w3c parameter may be entered here<br />e.g. <b><i>class='tbox' size='40' maxlength='80'</i></b>");
define("EXTLAN_52", "regex validation code");
define("EXTLAN_53", "Enter the regex code that will need to be matched to make it a valid entry <br />**regex delimiters are required**");
define("EXTLAN_54", "regex failure text");
define("EXTLAN_55", "Enter the error message that will be shown if the regex validation fails.");
define("EXTLAN_56", "Predefined Fields");
define("EXTLAN_57", "Activated");
define("EXTLAN_58", "Not Activated");
define("EXTLAN_59", "Activate");
define("EXTLAN_60", "Deactivate");
define("EXTLAN_61", "None");

define("EXTLAN_62", "Table");
define("EXTLAN_63", "Field Id");
define("EXTLAN_64", "Display Value");

define("EXTLAN_65", "No - Will not show on signup page");
define("EXTLAN_66", "Yes - Will show on signup page");
define("EXTLAN_67", "No - Show on signup page");

define("EXTLAN_68", "Field:");
define("EXTLAN_69", "has been activated");
define("EXTLAN_70", "ERROR!! Field:");
define("EXTLAN_71", "was not activated!");
define("EXTLAN_72", "has been deactivated");
define("EXTLAN_73", "was not deactivated!");
define("EXTLAN_74", "is a reserved field name and can not be used.");
define("EXTLAN_75", "Error adding field to database.");
define("EXTLAN_76", "Invalid characters in field name - only A-Z, a-z, 0-9, '_' allowed.");
define("EXTLAN_77", "Category not deleted - must delete fields in category first: ");
define('EXTLAN_78', 'Cannot find file --FILE-- needed to create data table');


//textbox
define("EXTLAN_HELP_1", "<b><i>Parameters:</i></b><br />size - size of field<br />maxlength - max length of field<br /><br />class - css class of field<br />style - css style string<br /><br />regex - regex validation code<br />regexfail - validation fail text");
//radio buttons
define("EXTLAN_HELP_2", "Enter text for options in 'Values' box - one box per option. Add new boxes as needed");
//dropdown
define("EXTLAN_HELP_3", "Enter text for options in 'Values' box - one box per option. Add new boxes as needed");
//db field
define("EXTLAN_HELP_4", "<b><i>Values:</i></b><br />There should be three values given ALWAYS:<br /><ol><li>dbtable</li><li>field containing id</li><li>field containing value</li></ol><br />");
//textarea
define("EXTLAN_HELP_5", "Define an area for free-format text. (Set the size in the 'Field include text' box as required)");
//integer
define("EXTLAN_HELP_6", "Allow user to enter a numeric value");
//date
define("EXTLAN_HELP_7", "Require user to enter a date");
// Language
define("EXTLAN_HELP_8", "Allow user to select from installed languages");

?>

==> e107_0.7.25_full.tar.gz: e107_languages/English/admin/lan_users_extended.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_languages/English/admin/lan_users_extended.php $
|     $Revision: 11678 $
|     $Id: lan_users_extended.php 11678 2010-08-22 00:43:45Z e107coders $
|     $Author: e107coders $
+----------------------------------------------------------------------------+
*/
define("EXTLAN_1", "Name");
define("EXTLAN_2", "Preview");
define("EXTLAN_3", "Values");
define("EXTLAN_4", "Req'd");
define("EXTLAN_5", "Applicable");
define("EXTLAN_6", "Read access");
define("EXTLAN_7", "Write access");
define("EXTLAN_8", "Action");
define("EXTLAN_9", "Extended User Fields");

define("EXTLAN_10", "Field name");
define("EXTLAN_11", "This is the name of the field as stored in the table, it must be unique from any other, and must not be used in the main user table");
define("EXTLAN_12", "Field text");
define("EXTLAN_13", "This is the displayed name of the field in rendered pages");
define("EXTLAN_14", "Field Type");
define("EXTLAN_15", "Field include text");
define("EXTLAN_16", "Default Value");
define("EXTLAN_17", "Enter each possible value on each line <br /> For DB table see help.");
define("EXTLAN_18", "Required");
define("EXTLAN_19", "Users will be required to enter a value in this field when updating their settings.");
define("EXTLAN_20", "Determines which users this field will apply to.");
define("EXTLAN_21", "This will determine who will see this field in their usersettings.");
define("EXTLAN_22", "This will determine who can see the value in the user page <br />NOTE: Setting this to 'Read Only' will make it visible to Admin and the member only.");
define("EXTLAN_23", "Add Extended Field");
define("EXTLAN_24", "Update Extended Field");
define("EXTLAN_25", "move down");
define("EXTLAN_26", "move up");
define("EXTLAN_27", "Confirm Delete");
define("EXTLAN_28", "No extended fields defined");
define("EXTLAN_29", "Extended user fields saved.");
define("EXTLAN_30", "Extended field deleted");
// define("EXTLAN_31", "Extended Field Menu");
// define("EXTLAN_32", "Extended front page");
define("EXTLAN_33", "Cancel Edit");
define("EXTLAN_34", "Extended Fields");
define("EXTLAN_35", "Categories");
define("EXTLAN_36", "No assigned Category");
define("EXTLAN_37", "No categories defined");
define("EXTLAN_38", "Category name");
define("EXTLAN_39", "Add category");
define("EXTLAN_40", "Category created");
define("EXTLAN_41", "Category deleted");
define("EXTLAN_42", "Update Category");
define("EXTLAN_43", "Category Updated");
define("EXTLAN_44", "Category");
define("EXTLAN_45", "Add New Field");
define("EXTLAN_46", "Help");
define("EXTLAN_47", "Add new parameter");
define("EXTLAN_48", "Add new value");
define("EXTLAN_49", "Allow user to hide");
define("EXTLAN_50", "Setting this to yes will allow the user to hide this value from non-admins");
define("EXTLAN_51", "Any valid w3c parameter may be entered here<br />e.g. <b><i>class='tbox' size='40' maxlength='80'</i></b>");
define("EXTLAN_52", "regex validation code");
define("EXTLAN_53", "Enter the regex code that will need to be matched to make it a valid entry <br />**regex delimiters are required**");
define("EXTLAN_54", "regex failure text");
define("EXTLAN_55", "Enter the error message that will be shown if the regex validation fails.");
define("EXTLAN_56", "Predefined Fields");
define("EXTLAN_57", "Activated");
define("EXTLAN_58", "Not Activated");
define("EXTLAN_59", "Activate");
define("EXTLAN_60", "Deactivate");
define("EXTLAN_61", "None");

define("EXTLAN_62", "Table");
define("EXTLAN_63", "Field Id");
define("EXTLAN_64", "Display Value");

define("EXTLAN_65", "No - Will not show on signup page");
define("EXTLAN_66", "Yes - Will show on signup page");
define("EXTLAN_67", "No - Show on signup page");

define("EXTLAN_68", "Field:");
define("EXTLAN_69", "has been activated");
define("EXTLAN_70", "ERROR!! Field:");
define("EXTLAN_71", "was not activated!");
define("EXTLAN_72", "has been deactivated");
define("EXTLAN_73", "was not deactivated!");
define("EXTLAN_74", "is a reserved field name and can not be used.");
define("EXTLAN_75", "Error adding field to database.");
define("EXTLAN_76", "Invalid characters in field name - only A-Z, a-z, 0-9, '_' allowed.");
define("EXTLAN_77", "Category not deleted - must delete fields in category first: ");
define('EXTLAN_78', 'Cannot find file --FILE-- needed to create data table');


//textbox
define("EXTLAN_HELP_1", "<b><i>Parameters:</i></b><br />size - size of field<br />maxlength - max length of field<br /><br />class - css class of field<br />style - css style string<br /><br />regex - regex validation code<br />regexfail - validation fail text");
//radio buttons
define("EXTLAN_HELP_2", "Enter text for options in 'Values' box - one box per option. Add new boxes as needed");
//dropdown
define("EXTLAN_HELP_3", "Enter text for options in 'Values' box - one box per option. Add new boxes as needed");
//db field
define("EXTLAN_HELP_4", "<b><i>Values:</i></b><br />There should be three values given ALWAYS:<br /><ol><li>dbtable</li><li>field containing id</li><li>field containing value</li></ol><br />");
//textarea
define("EXTLAN_HELP_5", "Define an area for free-format text. (Set the size in the 'Field include text' box as required)");
//integer
define("EXTLAN_HELP_6", "Allow user to enter a numeric value");
//date
define("EXTLAN_HELP_7", "Require user to enter a date");
// Language
define("EXTLAN_HELP_8", "Allow user to select from installed languages");

?>
